<?php
/*******************************************************************
 *			
 * 			Fichier			:	mssql.php 
 * 			Cr le			:	12 septembre 2002 
 * 			Dernire modif	:	27 avril 2003 
 * 			Email			:	wascripts@phpcodeur.net 
 * 
 * 				Copyright  2002-2003 phpCodeur
 * 
 *******************************************************************/

/*******************************************************************
 *  This program is free software; you can redistribute it and/or 
 * 	modify it under the terms of the GNU General Public License as 
 * 	published by the Free Software Foundation; either version 2 of 
 *  the License, or (at your option) any later version. 
 *******************************************************************/


if( !defined('DATABASE') )
{

define('DATABASE', 'mssql'); 

class sql 
{
	var $connect_id;
	var $query_result; 
	var $trc_started = 0; 
	
	var $sql_error = array('errno' => '', 'message' => '', 'query' => ''); 
	
	function sql($dbhost, $dbuser, $dbpwd, $dbname, $persistent = false)
	{
		$sql_connect = ( $persistent ) ? 'mssql_pconnect' : 'mssql_connect'; 
		
		$this->connect_id = @$sql_connect($dbhost, $dbuser, $dbpwd); 
		
		if( $this->connect_id )
		{
			$select_db = @mssql_select_db($dbname, $this->connect_id); 
		
			if( !$select_db )
			{
				@mssql_close($this->connect_id);
			}
		}
	}
	
	function query_build($query_type, $table, $query_data, $sql_where = '')
	{
		$fields = $values = array(); 
		
		foreach( $query_data AS $field => $value )
		{
			$fields[] = $field; 
			
			if( is_bool($value) || is_numeric($value) )
			{
				$values[] = intval($value); 
			}
			else
			{
				$values[] = '\'' . $value . '\''; 
			}
		}
		
		if( $query_type == 'INSERT' )
		{
			$query_string  = 'INSERT INTO ' . $table . ' '; 
			$query_string .= '(' . implode(', ', $fields) . ') VALUES(' . implode(', ', $values) . ')'; 
		}
		else if( $query_type == 'UPDATE' )
		{
			$query_string  = 'UPDATE ' . $table . ' SET '; 
			for( $i = 0; $i < count($fields); $i++ )
			{
				$query_string .= ( $i > 0 ) ? ', ' : ''; 
				$query_string .= $fields[$i] . ' = ' . $values[$i]; 
			}
			
			if( is_array($sql_where) && count($sql_where) )
			{
				$ary = array(); 
				foreach( $sql_where AS $field => $value )
				{
					$ary[] = $field . ' = ' . $value; 
				}
				
				$query_string .= ' WHERE ' . implode(' AND ', $ary); 
			}
		}
		
		return $this->query($query_string); 
	}
	
	function query($query, $start = null, $limit = null)
	{
		unset($this->query_result); 
		
		if( isset($start) && isset($limit) )
		{
			$query = preg_replace('/^SELECT (.+)$/is', 'SELECT TOP ' . ($start + $limit) . ' \\1', $query); 
		}
		
		$this->query_result = @mssql_query($query, $this->connect_id); 
		
		if( $this->query_result )
		{
			$this->sql_error = array('errno' => '', 'message' => '', 'query' => ''); 
			
			return $this->query_result; 
		}
		else
		{
			$this->sql_error['errno'] 	= 0; 
			$this->sql_error['message'] = @mssql_get_last_message(); 
			$this->sql_error['query']	= $query; 
			
			if( $this->trc_started )
			{
				$this->transaction('ROLLBACK'); 
			}
						
			return false;
		}
	}
	
	function transaction($transaction)
	{
		switch($transaction)
		{
			case START_TRC:
				if( !$this->trc_started )
				{
					$this->trc_started = true; 
					$result = mssql_query('BEGIN', $this->connect_id); 
				}
				else
				{
					$result = true; 
				}
				break;
			
			case END_TRC:
				if( $this->trc_started )
				{
					$this->trc_started = false; 
					
					if( !($result = mssql_query('COMMIT', $this->connect_id)) )
					{
						mssql_query('ROLLBACK', $this->connect_id); 
						$result = false; 
					}
				}
				else
				{
					$result = true; 
				}
				break;
			
			case 'ROLLBACK':
				if( $this->trc_started )
				{
					$this->trc_started = false; 
					$result = mssql_query('ROLLBACK', $this->connect_id); 
				}
				else
				{
					$result = true; 
				}
				break;
		}
		
		return $result; 
	}
	
	function num_rows($result = false)
	{
		if( !$result )
		{
			$result = $this->query_result;
		}
		
		return ( $result ) ? @mssql_num_rows($result) : false;
	}
	
	function affected_rows()
	{
		return ( $this->connect_id ) ? @mssql_rows_affected($this->connect_id) : false;
	}
	
	function fetch_row($result = false)
	{
		if( !$result )
		{
			$result = $this->query_result;
		}
		
		return ( $result ) ? @mssql_fetch_row($result) : false;
	}
	
	function fetch_array($result = false)
	{
		if( !$result )
		{
			$result = $this->query_result;
		}
		
		return ( $result ) ? @mssql_fetch_array($result) : false;
	}
	
	function fetch_rowset($result = false)
	{
		if( !$result )
		{
			$result = $this->query_result; 
		}
		
		$rowset = array(); 
		while( $row = @mssql_fetch_array($result) )
		{
			$rowset[] = $row;
		}
		
		return $rowset; 
	}
	
	function num_fields($result = false)
	{
		if( !$result )
		{
			$result = $this->query_result;
		}
		
		return ( $result ) ? @mssql_num_fields($result) : false; 
	}
	
	function field_name($offset, $result = false)
	{
		if( !$result )
		{
			$result = $this->query_result;
		}
		
		return ( $result ) ? @mssql_field_name($result, $offset) : false; 
	}
	
	function result($result, $row, $field = '')
	{
		if( $field != '' )
		{
			return @mssql_result($result, $row, $field);
		}
		else
		{
			return @mssql_result($result, $row);
		}
	}
	
	function next_id()
	{
		$result = @mssql_query('SELECT @@IDENTITY AS last_id', $this->connect_id);
		
		return @mssql_result($result, 0, 'last_id'); 
	}
	
	function free_result($result = false)
	{
		if( !$result )
		{
			$result = $this->query_result;
		}
		
		@mssql_free_result($result); 
	}
	
	function close_connexion()
	{
		if( $this->connect_id )
		{
			if( $this->query_result )
			{
				$this->free_result();
			}
			
			if( $this->trc_started )
			{
				$this->transaction('COMMIT'); 
			}
			
			return @mssql_close($this->connect_id);
		}
		else
		{
			return false;
		}
	}
}// fin de la classe

}
?>